Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
The Fast Static Symbol Table (FSST) decoder.

See module level documentations. Note that this struct contains a ~2KiB large array, and you may want to box it for fast moving.

Implementations

Source

impl Decoder

pub const MAX_SYMBOL_LEN: usize = 8usize

The max length of one symbol.

pub fn parse(bytes: &[u8]) -> Result<Self, Error>

Parse the symbol table symtab, from the serialization format from libfstt.

This is re-implemented in Rust with the reference of libfstt’s fsst_import.

Some notable differences:

  • More error checking on short inputs, no buffer overflow, because we’re Rust.
  • More permissive on version endianness. Allow both little and big endian versions. Symbols are still always little-endian, as upstream.
  • Zero-terminated mode (NUL as the first symbol) is unsupported and rejected.
  • Encoder state bytes are ignored.
  • Trailing bytes are allowed but ignored.

License of libfstt: MIT License, Copyright 2018-2020, CWI, TU Munich, FSU Jena

Errors

Returns None if the input cannot be successfully parsed.

pub fn max_decode_len(input_len: usize) -> usize

Return the max possible decoded length of input_len length input.

pub fn decode_into( &self, input: &[u8], output: &mut [u8], ) -> Result<usize, Error>

Decode input into output and return the number of decoded length.

Errors

If output.len() < Self::max_decode_len(input.len()), or an error occurs during decoding, None is returned.

pub fn decode(&self, input: &[u8]) -> Result<BString, Error>

Decode input into an owned byte string.

Errors

If an error occurs during decoding, None is returned.